@@ -7,6 +7,7 @@ AnonFiles 的优点：
 1.免费 2.容量大 3.保存时间长 4.国内可直接访问 5.有API 6.匿名
 
 https://github.com/ahui2016/ffe/raw/main/recipes/anon.py
+# version: 2022-01-11
 """
 
 # 每个插件都应如上所示在文件开头写简单介绍，以便 "ffe install --peek" 功能窥视插件概要。
@@ -14,7 +15,7 @@ https://github.com/ahui2016/ffe/raw/main/recipes/anon.py
 import tomli
 import requests
 import pyperclip
-from ffe.model import Recipe, ErrMsg, must_exist, get_bool, names_limit
+from ffe.model import Recipe, ErrMsg, must_exist, get_bool, must_files, names_limit
 from ffe.util import app_config_file, get_proxies
 
 
@@ -36,12 +37,13 @@ names = [        # 每次只能上传一个文件
 [tasks.options]
 auto_copy = true  # 是否自动复制结果到剪贴板
 key = ""          # AnonFiles 账号的 key
-names = []        # 只有当多个任务组合时才使用此项代替命令行输入
+names = []  # 只有当多个任务组合时才使用此项代替命令行输入
 
 # 每次只能上传 1 个文件，如果需要一次性上传多个文件，建议先压缩打包。
 # 不设置 key 也可使用，如果注册了 AnonFiles 并且设置了 key, 可登入 AnonFiles 的账号查看已上传文件的列表。
 # 也可在 ffe-config.toml 里设置 key (参考 https://github.com/ahui2016/ffe/blob/main/examples/ffe-config.toml)
 # 你的 ffe-config.toml 文件位置可以用命令 `ffe info -cfg` 查看。
+# version: 2022-01-11
 """
 
     @property  # 必须设为 @property
@@ -80,7 +82,10 @@ names = []        # 只有当多个任务组合时才使用此项代替命令行
             return err
         self.filename = names[0]
 
-        return must_exist(names)
+        err = must_exist(names)
+        if err:
+            return err
+        return must_files(names)
 
     def dry_run(self) -> ErrMsg:
         assert self.is_validated, "在执行 dry_run 之前必须先执行 validate"
