@@ -1,7 +1,7 @@
 import sys
 import importlib.util
 from pathlib import Path
-from typing import Any, Dict, Tuple, Type, TypedDict, cast
+from typing import Any, Type, TypedDict, cast
 from abc import ABC, abstractmethod
 
 # 采用 ErrMsg 而不是采用 exception, 一来是受到 Go 语言的影响，
@@ -13,6 +13,8 @@ ErrMsg = str
 __input_files_max__ = 99
 """默认文件/文件夹数量上限(不是实际处理数量，而是输入参数个数)"""
 
+MB = 1024 * 1024
+"""用于方便计算文件体积"""
 
 class Recipe(ABC):
     @property
@@ -89,7 +91,7 @@ class Plan(TypedDict):
     tasks: list[Task]
 
 
-def new_plan(obj: Dict[str, Any] = None) -> Plan:
+def new_plan(obj: dict[str, Any] = None) -> Plan:
     plan = Plan(global_names=[], global_options={}, tasks=[])
     if not obj:
         return plan
@@ -214,6 +216,16 @@ def filter_files(names: list[Path]) -> list[Path]:
     return [x for x in names if x.is_file()]
 
 
+def filesize_limit(name: str | Path, limit: int) -> ErrMsg:
+    """限制文件体积不可超过 limit (单位:MB)"""
+    if isinstance(name, str):
+        name = Path(name)
+    filesize = name.lstat().st_size / MB
+    if filesize > limit:
+        return f"{name}\nfile size ({filesize:.2f} MB) exceeds the limit ({limit} MB)\n"
+    return ""
+
+
 def names_limit(
     names: list[str], min: int, max: int = __input_files_max__
 ) -> tuple[list[str], ErrMsg]:
@@ -236,7 +248,7 @@ def names_limit(
     return names, expected
 
 
-def get_bool(options: dict, key: str) -> Tuple[bool, ErrMsg]:
+def get_bool(options: dict, key: str) -> tuple[bool, ErrMsg]:
     v = options.get(key, False)
     if not isinstance(v, bool):
         return False, f"Please set {key} to 'true' or 'false'"
